@@ -31,19 +31,20 @@
 # The algorithm is (more or less) the same.
 
 
-addReact <- function(model,
-                     id,
-                     met,
-                     Scoef,
-                     reversible = FALSE,
-                     lb = 0,
-                     ub = SYBIL_SETTINGS("MAXIMUM"),
-                     obj = 0,
-                     subSystem = NA,
-                     gprAssoc = NA,
-                     reactName = NA,
-                     metName = NA,
-                     metComp = NA) {
+setMethod("addReact", signature(model = "modelorg"),
+	function(model,
+			id,
+			met,
+			Scoef,
+			reversible = FALSE,
+			lb = 0,
+			ub = SYBIL_SETTINGS("MAXIMUM"),
+			obj = 0,
+			subSystem = NA,
+			gprAssoc = NA,
+			reactName = NA,
+			metName = NA,
+			metComp = NA) {
 
   
     # ------------------------------------------------------------------------ #
@@ -185,7 +186,7 @@ addReact <- function(model,
             newRows <- Matrix::Matrix(0,
                                       nrow = nNewRows,
                                       ncol = react_num(model))
-            newS <- Matrix::rBind(newS, newRows)
+            newS <- rbind(newS, newRows)
             
             # new met attrs
             if(ncol(newMetAttr) > 0){
@@ -219,7 +220,7 @@ addReact <- function(model,
             newobj_coef  <- append(obj_coef(model),  obj)
 
             # new column in stoichiometric matrix
-            newS <- cBind(newS, rep(0, nrow(newS)))
+            newS <- cbind(newS, rep(0, nrow(newS)))
             
             # new react Attr
             # only one new row, /bc we can only add one reaction a time.
@@ -235,23 +236,23 @@ addReact <- function(model,
             		newsubSys <- ss
             	}
             	else {
-            		newsubSys <- rBind(ss, rep(FALSE, ncol(subSys(model))))
+            		newsubSys <- rbind(ss, rep(FALSE, ncol(subSys(model))))
             	}
             }
             else {
                 if (is(subSystem, "logical")) {
-                    newsubSys <- rBind(subSys(model), subSystem)
+                    newsubSys <- rbind(subSys(model), subSystem)
                 }
                 else {
                     nSubsRow  <- colnames(subSys(model)) %in% subSystem
-                    newsubSys <- rBind(subSys(model), nSubsRow)
+                    newsubSys <- rbind(subSys(model), nSubsRow)
                 }
             }
 
 
             # gpr association
             if (ncol(rxnGeneMat(model)) > 0) {
-                newrxnGeneMat   <- rBind(rxnGeneMat(model),
+                newrxnGeneMat   <- rbind(rxnGeneMat(model),
                                          rep(FALSE, ncol(rxnGeneMat(model))))
             }
             else { #if (nrow(rxnGeneMat(model)) > 0) {
@@ -293,7 +294,7 @@ addReact <- function(model,
                     }
                     else {
                         for (i in seq(along = gene_rule[["gene"]][new_gene])) {
-	    					newrxnGeneMat <- cBind(newrxnGeneMat,
+	    					newrxnGeneMat <- cbind(newrxnGeneMat,
 		    								   rep(FALSE, nrow(newrxnGeneMat)))
 			    		}
 					}
@@ -410,5 +411,5 @@ addReact <- function(model,
 
     return(mod_out)
 
-}
+})
 
