@@ -38,6 +38,10 @@ setGeneric(name = "addColsToProb",
            def  = function(lp, ...) { standardGeneric("addColsToProb") }
 )
 
+setGeneric(name = "addReact",
+           def  = function(model, ...) { standardGeneric("addReact") }
+)
+
 setGeneric(name = "addRows",
            def  = function(lp, nrows, ...) { standardGeneric("addRows") }
 )
@@ -351,6 +355,10 @@ setGeneric(name = "getObjVal",
            def  = function(lp) { standardGeneric("getObjVal") }
 )
 
+setGeneric(name = "getReaction",
+           def  = function(X, ...) { standardGeneric("getReaction") }
+)
+
 setGeneric(name = "getRedCosts",
            def  = function(lp) { standardGeneric("getRedCosts") }
 )
@@ -389,6 +397,13 @@ setGeneric(name = "gprRules<-",
            def  = function(object, value) { standardGeneric("gprRules<-") }
 )
 
+setGeneric(name = "gprRule",
+           def  = function(object) { standardGeneric("gprRule") }
+)
+setGeneric(name = "gprRule<-",
+           def  = function(object, value) { standardGeneric("gprRule<-") }
+)
+
 setGeneric(name = "hasEffect",
            def  = function(object) { standardGeneric("hasEffect") }
 )
@@ -869,6 +884,13 @@ setGeneric(name = "S<-",
            def  = function(object, value) { standardGeneric("S<-") }
 )
 
+setGeneric(name = "s",
+           def  = function(object) { standardGeneric("s") }
+)
+setGeneric(name = "s<-",
+           def  = function(object, value) { standardGeneric("s<-") }
+)
+
 setGeneric(name = "scaleProb",
            def  = function(lp, ...) { standardGeneric("scaleProb") }
 )
